@@ -5,9 +5,12 @@
 # Distributed under the terms of the GPL License.
 from copy import copy
 from typing import Any, Dict, List, Optional, Set, Tuple
+from mitosheet.code_chunks.code_chunk import CodeChunk
+from mitosheet.code_chunks.step_performers.dataframe_steps.dataframe_delete_code_chunk import DataframeDeleteCodeChunk
 
 from mitosheet.state import State
 from mitosheet.step_performers.step_performer import StepPerformer
+from mitosheet.step_performers.utils import get_param
 
 
 class DataframeDeleteStepPerformer(StepPerformer):
@@ -23,14 +26,6 @@ class DataframeDeleteStepPerformer(StepPerformer):
     def step_type(cls) -> str:
         return 'dataframe_delete'
 
-    @classmethod
-    def step_display_name(cls) -> str:
-        return 'Deleted a Dataframe'
-    
-    @classmethod
-    def step_event_type(cls) -> str:
-        return 'dataframe_delete_edit'
-
     @classmethod
     def saturate(cls, prev_state: State, params: Dict[str, Any]) -> Dict[str, Any]:
         sheet_index = params['sheet_index']
@@ -39,15 +34,10 @@ class DataframeDeleteStepPerformer(StepPerformer):
         return params
 
     @classmethod
-    def execute( # type: ignore
-        cls,
-        prev_state: State,
-        sheet_index: int,
-        old_dataframe_name: str,
-        **params
-    ) -> Tuple[State, Optional[Dict[str, Any]]]:
-        # Create a new step and save the parameters
-        post_state = copy(prev_state)
+    def execute(cls, prev_state: State, params: Dict[str, Any]) -> Tuple[State, Optional[Dict[str, Any]]]:
+        sheet_index: int = get_param(params, 'sheet_index')
+        
+        post_state = prev_state.copy()
 
         # Execute the delete
         post_state.column_ids.remove_df(sheet_index)
@@ -58,34 +48,32 @@ class DataframeDeleteStepPerformer(StepPerformer):
         post_state.df_names.pop(sheet_index)
         post_state.df_sources.pop(sheet_index)
 
-        return post_state, None
+        return post_state, {
+            'pandas_processing_time': 0 # No time spent on pandas, only metadata changes
+        }
 
     @classmethod
-    def transpile( # type: ignore
+    def transpile(
         cls,
         prev_state: State,
         post_state: State,
+        params: Dict[str, Any],
         execution_data: Optional[Dict[str, Any]],
-        sheet_index: int,
-        old_dataframe_name: str
-    ) -> List[str]:
-        return [f'del {old_dataframe_name}']
-
-    @classmethod
-    def describe( # type: ignore
-        cls,
-        sheet_index: int,
-        old_dataframe_name: str,
-        df_names=None,
-        **params
-    ) -> str:
-        return f'Deleted dataframe {old_dataframe_name}'
+    ) -> List[CodeChunk]:
+        return [
+            DataframeDeleteCodeChunk(
+                prev_state, 
+                post_state, 
+                # Our dataframe delete code chunk can support mulitple dataframes being deleted
+                # at once, so we turn it into this format
+                {
+                    'sheet_indexes': [params['sheet_index']],
+                    'old_dataframe_names': [params['old_dataframe_name']],
+                }, 
+                execution_data
+            )
+        ]
     
     @classmethod
-    def get_modified_dataframe_indexes( # type: ignore
-        cls, 
-        sheet_index: int,
-        old_dataframe_name: str,
-        **params
-    ) -> Set[int]:
+    def get_modified_dataframe_indexes(cls, params: Dict[str, Any]) -> Set[int]:
         return set() # Redo all of them, as order shifts
