@@ -39,7 +39,9 @@ from mitosheet.step_performers.fill_na import FillNaStepPerformer
 from mitosheet.step_performers.graph_steps.graph_delete import GraphDeleteStepPerformer
 from mitosheet.step_performers.graph_steps.graph_duplicate import GraphDuplicateStepPerformer
 from mitosheet.step_performers.graph_steps.graph_rename import GraphRenameStepPerformer
+from mitosheet.step_performers.melt import MeltStepPerformer
 from mitosheet.step_performers.promote_row_to_header import PromoteRowToHeaderStepPerformer
+from mitosheet.step_performers.transpose import TransposeStepPerformer
 
 def check_step(
         step_performer: StepPerformer, 
@@ -106,7 +108,7 @@ def test_params_static():
 
     check_step(
         MergeStepPerformer,
-        3,
+        4,
         'merge'
     )
 
@@ -244,7 +246,19 @@ def test_params_static():
         'split_text_to_columns'
     )
 
-    assert len(STEP_PERFORMERS) == 28
+    check_step(
+        TransposeStepPerformer,
+        1,
+        'transpose'
+    )
+
+    check_step(
+        MeltStepPerformer,
+        1,
+        'melt'
+    )
+
+    assert len(STEP_PERFORMERS) == 30
 
 
 def get_fake_param(param_name):
